<?php

namespace Neuron\Person;

use Neuron\Contact\Address as Address;
use Neuron\Contact\Address\City;
use Neuron\Generic\Result;
use Neuron\Generic\Set;
use Neuron\Person\Skill;

class Skills extends Set {
    
	protected $_storage;

	public function __construct(\Neuron\Person\Skill\Storage\Skeleton $storage) {

		$this->_storage = $storage;
	}

	public function listdata($params) {

	  	try {
	        $result = $this->_storage->listdata($params);
			
	        $retval = array(
	            'draw' => isset($params['draw'])? $params['draw'] : 0,
	            'recordsTotal' => $result['total'],
	            'recordsFiltered' => $result['total'],
	            'data' => $result['data'],
	        );

	        return $retval;
	    } catch (Exception $e) {
	        return $e;
	    }

	}

	public function load($ids = '', $mode = Skill\Storage::LIST_ALL, $params = array()){
        $result = new Result();
        try {
            /* clear list */
            $this->clear();

            if ($rs = $this->_storage->loadList($ids, $mode, $params)) {
                if ($rows = $rs->list) {
                    $rows = $rs->list;
                    $list = [];
                    foreach ($rows as $row) {
                        /* for issue oracle */
                        $row = array_change_key_case($row);
                        unset($row['b_rownum']);
                        /* new user */
                        $model = new Skill($this->_storage);
                        $model->push($row);
                        $this->add($model);
                        $list[] = $row;
                    }

                    $result->data = [
                        'pager' => $rs->pager,
                        'list' => $list,
                        'countTotal' => $rs->countTotal,
                    ];
                } else {
                    $result->data = [];
                    $result->code = 2;
                    $result->info = 'load_none';
                }
            } else {
                $result->data = [];
                $result->code = 1;
                $result->info = 'load_not_found';
            }

            return $result;
        } catch (Throwable $throwable) {
            error_log('Error at ' . $throwable->getFile() . ' line ' . $throwable->getLine() . ': ' . $throwable->getMessage());
            $result->code = 500;
            $result->info = 'error';
            return $result;
        }
    }
}